@@ -3,14 +3,17 @@ import hashlib
 
 class BaseChunker:
     def __init__(self, text_splitter):
+        """Initialize the chunker."""
         self.text_splitter = text_splitter
 
     def create_chunks(self, loader, src):
         """
         Loads data and chunks it.
 
-        :param loader: The loader which's `load_data` method is used to create the raw data.
-        :param src: The data to be handled by the loader. Can be a URL for remote sources or local content for local loaders. 
+        :param loader: The loader which's `load_data` method is used to create
+        the raw data.
+        :param src: The data to be handled by the loader. Can be a URL for
+        remote sources or local content for local loaders.
         """
         documents = []
         ids = []
@@ -22,11 +25,11 @@ class BaseChunker:
             meta_data = data["meta_data"]
             url = meta_data["url"]
 
-            chunks = self.text_splitter.split_text(content)
+            chunks = self.get_chunks(content)
 
             for chunk in chunks:
                 chunk_id = hashlib.sha256((chunk + url).encode()).hexdigest()
-                if (idMap.get(chunk_id) is None):
+                if idMap.get(chunk_id) is None:
                     idMap[chunk_id] = True
                     ids.append(chunk_id)
                     documents.append(chunk)
@@ -36,3 +39,11 @@ class BaseChunker:
             "ids": ids,
             "metadatas": metadatas,
         }
+
+    def get_chunks(self, content):
+        """
+        Returns chunks using text splitter instance.
+
+        Override in child class if custom logic.
+        """
+        return self.text_splitter.split_text(content)
\ No newline at end of file
