@@ -4,8 +4,8 @@ from embedchain.utils import clean_string
 
 
 class YoutubeVideoLoader:
-
     def load_data(self, url):
+        """Load data from a Youtube video."""
         loader = YoutubeLoader.from_youtube_url(url, add_video_info=True)
         doc = loader.load()
         output = []
@@ -15,8 +15,10 @@ class YoutubeVideoLoader:
         content = clean_string(content)
         meta_data = doc[0].metadata
         meta_data["url"] = url
-        output.append({
-            "content": content,
-            "meta_data": meta_data,
-        })
+        output.append(
+            {
+                "content": content,
+                "meta_data": meta_data,
+            }
+        )
         return output
